@@ -1,4 +1,4 @@
-#' A more flexible version of [all.equal].
+#' A more flexible version of [all.equal] for vectors.
 #'
 #' If one argument is specified, check that all elements of that argument are
 #' equal. If two arguments of equal length are specified, check equality of all
@@ -9,18 +9,18 @@
 #' `a` are equal to the element in `b`.
 #'
 #' @param a A vector.
-#' @param b Either `NULL` or a vector of length either 1 or `length(a)`
+#' @param b Either `NULL` or a vector of length either 1 or `length(a)`.
 #' @return `TRUE` if "equality of all" is satisfied (as detailed in
 #'   "Description" above) and `FALSE` otherwise.
 #' @examples
-#' AllEqual(1, rep(1, 3))
-#' AllEqual(2, 1:3)
-#' AllEqual(1:4, 1:4)
-#' AllEqual(1:4, c(1, 2, 3, 3))
-#' AllEqual(rep(1, 10))
-#' AllEqual(c(1, 88))
+#' all_equal(1, rep(1, 3))
+#' all_equal(2, 1:3)
+#' all_equal(1:4, 1:4)
+#' all_equal(1:4, c(1, 2, 3, 3))
+#' all_equal(rep(1, 10))
+#' all_equal(c(1, 88))
 #' @export
-AllEqual <- function(a, b = NULL) {
+all_equal <- function(a, b = NULL) {
   if (is.null(a) && (!is.null(b))) return(FALSE)
   if (is.null(b[1])) {
     return(length(unique(a)) == 1)
@@ -44,40 +44,40 @@ AllEqual <- function(a, b = NULL) {
 #' separeted by at most some specified distance. Hence, each element in each
 #' group has at least one other element in that group that is \emph{close} to
 #' it. See the examples.
-#' @param vec.ascending A strictly increasing numeric vector.
-#' @param max.gap The biggest allowable gap between adjacent elements for them
+#' @param vec_ascending A strictly increasing numeric vector.
+#' @param max_gap The biggest allowable gap between adjacent elements for them
 #'   to be considered part of the same \emph{group}.
 #' @return A where each element is one group, as a numeric vector.
 #' @examples
-#' GroupClose(1:10, 1)
-#' GroupClose(1:10, 0.5)
-#' GroupClose(c(1, 2, 4, 10, 11, 14, 20, 25, 27), 3)
+#' group_close(1:10, 1)
+#' group_close(1:10, 0.5)
+#' group_close(c(1, 2, 4, 10, 11, 14, 20, 25, 27), 3)
 #' @export
-GroupClose <- function(vec.ascending, max.gap = 1) {
-  lv <- length(vec.ascending)
-  if (lv == 0) stop("vec.ascending must have length greater than zero.")
-  test <- all(diff(vec.ascending) > 0)
-  if (is.na(test) || !test) stop("vec.ascending must be strictly increasing.")
+group_close <- function(vec_ascending, max_gap = 1) {
+  lv <- length(vec_ascending)
+  if (lv == 0) stop("vec_ascending must have length greater than zero.")
+  test <- all(diff(vec_ascending) > 0)
+  if (is.na(test) || !test) stop("vec_ascending must be strictly increasing.")
   if (lv == 1) {
-    return(list(vec.ascending))
+    return(list(vec_ascending))
   } else {
-    gaps <- vec.ascending[2:lv] - vec.ascending[1:(lv-1)]
-    big.gaps <- gaps > max.gap
-    nbgaps <- sum(big.gaps)  # number of big gaps
+    gaps <- vec_ascending[2:lv] - vec_ascending[1:(lv-1)]
+    big_gaps <- gaps > max_gap
+    nbgaps <- sum(big_gaps)  # number of big gaps
     if (!nbgaps) {
-      return(list(vec.ascending))
+      return(list(vec_ascending))
     } else {
-      ends <- which(big.gaps)  # vertical end of lines
-      group1 <- vec.ascending[1:ends[1]]
+      ends <- which(big_gaps)  # vertical end of lines
+      group1 <- vec_ascending[1:ends[1]]
       lg <- list(group1)
       if (nbgaps == 1){
-        lg[[2]] <- vec.ascending[(ends[1] + 1):lv]
+        lg[[2]] <- vec_ascending[(ends[1] + 1):lv]
       } else {
         for (i in 2:nbgaps){
-          lg[[i]] <- vec.ascending[(ends[i - 1] + 1):ends[i]]
+          lg[[i]] <- vec_ascending[(ends[i - 1] + 1):ends[i]]
           ikeep <- i
         }
-        lg[[ikeep + 1]] <- vec.ascending[(ends[nbgaps] + 1):lv]
+        lg[[ikeep + 1]] <- vec_ascending[(ends[nbgaps] + 1):lv]
       }
       return(lg)
     }
